==> binnie-mods-1.11.2-2.1.0.36-sources.jar: binnie/extratrees/block/BlockHops.java <==
package binnie.extratrees.block;

import java.util.List;
import java.util.Locale;
import java.util.Random;

import net.minecraft.block.Block;
import net.minecraft.block.BlockCrops;
import net.minecraft.block.properties.PropertyEnum;
import net.minecraft.block.state.BlockStateContainer;
import net.minecraft.block.state.IBlockState;
import net.minecraft.entity.EntityLivingBase;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.init.Blocks;
import net.minecraft.init.Items;
import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.util.EnumFacing;
import net.minecraft.util.EnumHand;
import net.minecraft.util.IStringSerializable;
import net.minecraft.util.NonNullList;
import net.minecraft.util.math.AxisAlignedBB;
import net.minecraft.util.math.BlockPos;
import net.minecraft.world.IBlockAccess;
import net.minecraft.world.World;

import net.minecraftforge.common.EnumPlantType;

import binnie.extratrees.ExtraTrees;

public class BlockHops extends BlockCrops{
	public static final PropertyEnum<HopsHalf> HALF = PropertyEnum.func_177709_a("half", HopsHalf.class);
	
	public BlockHops() {
		this.func_180632_j(this.field_176227_L.func_177621_b().func_177226_a(func_185524_e(), 0).func_177226_a(HALF, HopsHalf.DOWN));
		func_149663_c("hops");
		setRegistryName("hops");
	}
	
	@Override
	public boolean func_180639_a(World world, BlockPos pos, IBlockState state, EntityPlayer playerIn, EnumHand hand, EnumFacing facing, float hitX, float hitY, float hitZ) {
		state = func_176221_a(state, world, pos);
		int age = func_185527_x(state);
		if(age == func_185526_g()) {
			if (!world.field_72995_K) {
				List<ItemStack> items = NonNullList.func_191196_a();
				items.addAll(getDrops(world, pos, state, 0));
				
				for (ItemStack item : items) {
					func_180635_a(world, pos, item);
				}
				BlockPos cropPos = pos;
				if(state.func_177229_b(HALF) == HopsHalf.UP){
					cropPos = cropPos.func_177977_b();
				}
				placeAt(world, cropPos, 2);
			}
			return true;
		}
		return false;
	}
	
	@Override
	protected int func_185529_b(World worldIn) {
		return super.func_185529_b(worldIn) / 2;
	}
	
	@Override
	public AxisAlignedBB func_185496_a(IBlockState state, IBlockAccess source, BlockPos pos) {
		return field_185505_j;
	}
	
	@Override
	public EnumPlantType getPlantType(IBlockAccess world, BlockPos pos) {
		return EnumPlantType.Crop;
	}
	
	public boolean func_176196_c(World worldIn, BlockPos pos) {
		return super.func_176196_c(worldIn, pos) && worldIn.func_175623_d(pos.func_177984_a());
	}
	
	@Override
	protected void func_176475_e(World worldIn, BlockPos pos, IBlockState state) {
		if (!this.func_180671_f(worldIn, pos, state)) {
			boolean flag = state.func_177229_b(HALF) == HopsHalf.UP;
			BlockPos blockpos = flag ? pos : pos.func_177984_a();
			BlockPos blockpos1 = flag ? pos.func_177977_b() : pos;
			Block block = flag ? this : worldIn.func_180495_p(blockpos).func_177230_c();
			Block block1 = flag ? worldIn.func_180495_p(blockpos1).func_177230_c() : this;
			
			if (!flag){
				this.func_176226_b(worldIn, pos, state, 0);
			}
			
			if (block == this) {
				worldIn.func_180501_a(blockpos, Blocks.field_150350_a.func_176223_P(), 2);
			}
			
			if (block1 == this) {
				worldIn.func_180501_a(blockpos1, Blocks.field_150350_a.func_176223_P(), 3);
			}
		}
	}
	
	@Override
	public boolean func_180671_f(World worldIn, BlockPos pos, IBlockState state) {
		if (state.func_177229_b(HALF) == HopsHalf.UP) {
			return worldIn.func_180495_p(pos.func_177977_b()).func_177230_c() == this;
		} else {
			IBlockState iblockstate = worldIn.func_180495_p(pos.func_177984_a());
			return iblockstate.func_177230_c() == this && super.func_180671_f(worldIn, pos, iblockstate);
		}
	}
	
	@Override
	public Item func_180660_a(IBlockState state, Random rand, int fortune) {
		if (state.func_177229_b(HALF) == HopsHalf.UP) {
			return Items.field_190931_a;
		} else {
			return super.func_180660_a(state, rand, fortune);
		}
	}
	
	@Override
	protected Item func_149865_P() {
		return ExtraTrees.items().itemHops;
	}
	
	@Override
	protected Item func_149866_i() {
		return ExtraTrees.items().itemHops;
	}
	
	public void placeAt(World worldIn, BlockPos lowerPos, int flags) {
		worldIn.func_180501_a(lowerPos, this.func_176223_P().func_177226_a(HALF, HopsHalf.DOWN), flags);
		worldIn.func_180501_a(lowerPos.func_177984_a(), this.func_176223_P().func_177226_a(HALF, HopsHalf.UP), flags);
	}
	
	public void func_180633_a(World worldIn, BlockPos pos, IBlockState state, EntityLivingBase placer, ItemStack stack) {
		worldIn.func_180501_a(pos.func_177984_a(), this.func_176223_P().func_177226_a(HALF, HopsHalf.UP), 2);
	}
	
	public void func_176208_a(World worldIn, BlockPos pos, IBlockState state, EntityPlayer player) {
		if (state.func_177229_b(HALF) == HopsHalf.UP) {
			if (worldIn.func_180495_p(pos.func_177977_b()).func_177230_c() == this) {
				if (player.field_71075_bZ.field_75098_d) {
					worldIn.func_175698_g(pos.func_177977_b());
				} else {
					worldIn.func_175655_b(pos.func_177977_b(), true);
				}
			}
		} else if (worldIn.func_180495_p(pos.func_177984_a()).func_177230_c() == this) {
			worldIn.func_180501_a(pos.func_177984_a(), Blocks.field_150350_a.func_176223_P(), 2);
		}
		
		super.func_176208_a(worldIn, pos, state, player);
	}
	
	@Override
	public ItemStack func_185473_a(World worldIn, BlockPos pos, IBlockState state) {
		return new ItemStack(func_149865_P());
	}
	
	@Override
	public boolean func_176473_a(World world, BlockPos pos, IBlockState state, boolean isClient) {
		if(state.func_177229_b(HALF) == HopsHalf.UP){
			IBlockState stateDrown = world.func_180495_p(pos.func_177977_b());
			Block block = stateDrown.func_177230_c();
			if(block instanceof BlockHops) {
				return ((BlockHops) block).func_176473_a(world, pos.func_177977_b(), stateDrown, isClient);
			}
			return false;
		}
		return super.func_176473_a(world, pos, state, isClient);
	}
	
	@Override
	public void func_176487_g(World world, BlockPos pos, IBlockState state) {
		if(state.func_177229_b(HALF) == HopsHalf.UP){
			IBlockState stateDrown = world.func_180495_p(pos.func_177977_b());
			Block block = stateDrown.func_177230_c();
			if(block instanceof BlockHops) {
				((BlockHops) block).func_176487_g(world, pos.func_177977_b(), stateDrown);
			}
			return;
		}
		super.func_176487_g(world, pos, state);
	}
	
	@Override
	public void func_180650_b(World worldIn, BlockPos pos, IBlockState state, Random rand) {
		if(state.func_177229_b(HALF) == HopsHalf.DOWN){
			super.func_180650_b(worldIn, pos, state, rand);
		}else {
			func_176475_e(worldIn, pos, state);
		}
	}
	
	@Override
	public boolean removedByPlayer(IBlockState state, World world, BlockPos pos, EntityPlayer player, boolean willHarvest) {
		if (state.func_177230_c() ==  this && state.func_177229_b(HALF) == HopsHalf.DOWN && world.func_180495_p(pos.func_177984_a()).func_177230_c() == this) {
			world.func_175698_g(pos.func_177984_a());
		}
		return world.func_175698_g(pos);
	}
	
	@Override
	protected BlockStateContainer func_180661_e() {
		return new BlockStateContainer(this, field_176488_a, HALF);
	}
	
	public IBlockState func_176203_a(int meta) {
		return (meta & 8) > 0 ? this.func_176223_P().func_177226_a(HALF, HopsHalf.UP) : this.func_176223_P().func_177226_a(HALF, HopsHalf.DOWN).func_177226_a(func_185524_e(), meta & 7);
	}
	
	@Override
	public IBlockState func_176221_a(IBlockState state, IBlockAccess worldIn, BlockPos pos) {
		if (state.func_177229_b(HALF) == HopsHalf.UP) {
			IBlockState iblockstate = worldIn.func_180495_p(pos.func_177977_b());
			
			if (iblockstate.func_177230_c() == this) {
				state = state.func_177226_a(func_185524_e(), iblockstate.func_177229_b(func_185524_e()));
			}
		}
		
		return state;
	}
	
	@Override
	public int func_176201_c(IBlockState state) {
		return state.func_177229_b(HALF) == HopsHalf.UP ? 8 : func_185527_x(state);
	}
	
	public enum HopsHalf implements IStringSerializable {
		UP,
		DOWN;
		
		@Override
		public String toString()
		{
			return this.func_176610_l();
		}
		
		@Override
		public String func_176610_l()
		{
			return name().toLowerCase(Locale.ENGLISH);
		}
	}
}

==> binnie-mods-1.11.2-2.1.0.38-sources.jar: binnie/extratrees/block/BlockHops.java <==
package binnie.extratrees.block;

import java.util.List;
import java.util.Locale;
import java.util.Random;

import net.minecraft.block.Block;
import net.minecraft.block.BlockCrops;
import net.minecraft.block.properties.PropertyEnum;
import net.minecraft.block.state.BlockStateContainer;
import net.minecraft.block.state.IBlockState;
import net.minecraft.entity.EntityLivingBase;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.init.Blocks;
import net.minecraft.init.Items;
import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.util.EnumFacing;
import net.minecraft.util.EnumHand;
import net.minecraft.util.IStringSerializable;
import net.minecraft.util.NonNullList;
import net.minecraft.util.math.AxisAlignedBB;
import net.minecraft.util.math.BlockPos;
import net.minecraft.world.IBlockAccess;
import net.minecraft.world.World;

import net.minecraftforge.common.EnumPlantType;

import binnie.extratrees.core.ModuleCore;

public class BlockHops extends BlockCrops{
	public static final PropertyEnum<HopsHalf> HALF = PropertyEnum.func_177709_a("half", HopsHalf.class);
	
	public BlockHops() {
		this.func_180632_j(this.field_176227_L.func_177621_b().func_177226_a(func_185524_e(), 0).func_177226_a(HALF, HopsHalf.DOWN));
		func_149663_c("hops");
		setRegistryName("hops");
	}
	
	@Override
	public boolean func_180639_a(World world, BlockPos pos, IBlockState state, EntityPlayer playerIn, EnumHand hand, EnumFacing facing, float hitX, float hitY, float hitZ) {
		state = func_176221_a(state, world, pos);
		int age = func_185527_x(state);
		if(age == func_185526_g()) {
			if (!world.field_72995_K) {
				List<ItemStack> items = NonNullList.func_191196_a();
				items.addAll(getDrops(world, pos, state, 0));
				
				for (ItemStack item : items) {
					func_180635_a(world, pos, item);
				}
				BlockPos cropPos = pos;
				if(state.func_177229_b(HALF) == HopsHalf.UP){
					cropPos = cropPos.func_177977_b();
				}
				placeAt(world, cropPos, 2);
			}
			return true;
		}
		return false;
	}
	
	@Override
	protected int func_185529_b(World worldIn) {
		return super.func_185529_b(worldIn) / 2;
	}
	
	@Override
	public AxisAlignedBB func_185496_a(IBlockState state, IBlockAccess source, BlockPos pos) {
		return field_185505_j;
	}
	
	@Override
	public EnumPlantType getPlantType(IBlockAccess world, BlockPos pos) {
		return EnumPlantType.Crop;
	}
	
	public boolean func_176196_c(World worldIn, BlockPos pos) {
		return super.func_176196_c(worldIn, pos) && worldIn.func_175623_d(pos.func_177984_a());
	}
	
	@Override
	protected void func_176475_e(World worldIn, BlockPos pos, IBlockState state) {
		if (!this.func_180671_f(worldIn, pos, state)) {
			boolean flag = state.func_177229_b(HALF) == HopsHalf.UP;
			BlockPos blockpos = flag ? pos : pos.func_177984_a();
			BlockPos blockpos1 = flag ? pos.func_177977_b() : pos;
			Block block = flag ? this : worldIn.func_180495_p(blockpos).func_177230_c();
			Block block1 = flag ? worldIn.func_180495_p(blockpos1).func_177230_c() : this;
			
			if (!flag){
				this.func_176226_b(worldIn, pos, state, 0);
			}
			
			if (block == this) {
				worldIn.func_180501_a(blockpos, Blocks.field_150350_a.func_176223_P(), 2);
			}
			
			if (block1 == this) {
				worldIn.func_180501_a(blockpos1, Blocks.field_150350_a.func_176223_P(), 3);
			}
		}
	}
	
	@Override
	public boolean func_180671_f(World worldIn, BlockPos pos, IBlockState state) {
		if (state.func_177229_b(HALF) == HopsHalf.UP) {
			return worldIn.func_180495_p(pos.func_177977_b()).func_177230_c() == this;
		} else {
			IBlockState iblockstate = worldIn.func_180495_p(pos.func_177984_a());
			return iblockstate.func_177230_c() == this && super.func_180671_f(worldIn, pos, iblockstate);
		}
	}
	
	@Override
	public Item func_180660_a(IBlockState state, Random rand, int fortune) {
		if (state.func_177229_b(HALF) == HopsHalf.UP) {
			return Items.field_190931_a;
		} else {
			return super.func_180660_a(state, rand, fortune);
		}
	}
	
	@Override
	protected Item func_149865_P() {
		return ModuleCore.itemHops;
	}
	
	@Override
	protected Item func_149866_i() {
		return ModuleCore.itemHops;
	}
	
	public void placeAt(World worldIn, BlockPos lowerPos, int flags) {
		worldIn.func_180501_a(lowerPos, this.func_176223_P().func_177226_a(HALF, HopsHalf.DOWN), flags);
		worldIn.func_180501_a(lowerPos.func_177984_a(), this.func_176223_P().func_177226_a(HALF, HopsHalf.UP), flags);
	}
	
	public void func_180633_a(World worldIn, BlockPos pos, IBlockState state, EntityLivingBase placer, ItemStack stack) {
		worldIn.func_180501_a(pos.func_177984_a(), this.func_176223_P().func_177226_a(HALF, HopsHalf.UP), 2);
	}
	
	public void func_176208_a(World worldIn, BlockPos pos, IBlockState state, EntityPlayer player) {
		if (state.func_177229_b(HALF) == HopsHalf.UP) {
			if (worldIn.func_180495_p(pos.func_177977_b()).func_177230_c() == this) {
				if (player.field_71075_bZ.field_75098_d) {
					worldIn.func_175698_g(pos.func_177977_b());
				} else {
					worldIn.func_175655_b(pos.func_177977_b(), true);
				}
			}
		} else if (worldIn.func_180495_p(pos.func_177984_a()).func_177230_c() == this) {
			worldIn.func_180501_a(pos.func_177984_a(), Blocks.field_150350_a.func_176223_P(), 2);
		}
		
		super.func_176208_a(worldIn, pos, state, player);
	}
	
	@Override
	public ItemStack func_185473_a(World worldIn, BlockPos pos, IBlockState state) {
		return new ItemStack(func_149865_P());
	}
	
	@Override
	public boolean func_176473_a(World world, BlockPos pos, IBlockState state, boolean isClient) {
		if(state.func_177229_b(HALF) == HopsHalf.UP){
			IBlockState stateDrown = world.func_180495_p(pos.func_177977_b());
			Block block = stateDrown.func_177230_c();
			if(block instanceof BlockHops) {
				return ((BlockHops) block).func_176473_a(world, pos.func_177977_b(), stateDrown, isClient);
			}
			return false;
		}
		return super.func_176473_a(world, pos, state, isClient);
	}
	
	@Override
	public void func_176487_g(World world, BlockPos pos, IBlockState state) {
		if(state.func_177229_b(HALF) == HopsHalf.UP){
			IBlockState stateDrown = world.func_180495_p(pos.func_177977_b());
			Block block = stateDrown.func_177230_c();
			if(block instanceof BlockHops) {
				((BlockHops) block).func_176487_g(world, pos.func_177977_b(), stateDrown);
			}
			return;
		}
		super.func_176487_g(world, pos, state);
	}
	
	@Override
	public void func_180650_b(World worldIn, BlockPos pos, IBlockState state, Random rand) {
		if(state.func_177229_b(HALF) == HopsHalf.DOWN){
			super.func_180650_b(worldIn, pos, state, rand);
		}else {
			func_176475_e(worldIn, pos, state);
		}
	}
	
	@Override
	public boolean removedByPlayer(IBlockState state, World world, BlockPos pos, EntityPlayer player, boolean willHarvest) {
		if (state.func_177230_c() ==  this && state.func_177229_b(HALF) == HopsHalf.DOWN && world.func_180495_p(pos.func_177984_a()).func_177230_c() == this) {
			world.func_175698_g(pos.func_177984_a());
		}
		return world.func_175698_g(pos);
	}
	
	@Override
	protected BlockStateContainer func_180661_e() {
		return new BlockStateContainer(this, field_176488_a, HALF);
	}
	
	public IBlockState func_176203_a(int meta) {
		return (meta & 8) > 0 ? this.func_176223_P().func_177226_a(HALF, HopsHalf.UP) : this.func_176223_P().func_177226_a(HALF, HopsHalf.DOWN).func_177226_a(func_185524_e(), meta & 7);
	}
	
	@Override
	public IBlockState func_176221_a(IBlockState state, IBlockAccess worldIn, BlockPos pos) {
		if (state.func_177229_b(HALF) == HopsHalf.UP) {
			IBlockState iblockstate = worldIn.func_180495_p(pos.func_177977_b());
			
			if (iblockstate.func_177230_c() == this) {
				state = state.func_177226_a(func_185524_e(), iblockstate.func_177229_b(func_185524_e()));
			}
		}
		
		return state;
	}
	
	@Override
	public int func_176201_c(IBlockState state) {
		return state.func_177229_b(HALF) == HopsHalf.UP ? 8 : func_185527_x(state);
	}
	
	public enum HopsHalf implements IStringSerializable {
		UP,
		DOWN;
		
		@Override
		public String toString()
		{
			return this.func_176610_l();
		}
		
		@Override
		public String func_176610_l()
		{
			return name().toLowerCase(Locale.ENGLISH);
		}
	}
}
